==> FjordLight_0.8.tar.gz: FjordLight/README.md <==
# FjordLight <img src="logo.png" width=200 align="right" />

[![CRAN_Status_Badge](http://www.r-pkg.org/badges/version/FjordLight)](https://cran.r-project.org/package=FjordLight)
[![R-CMD-check](https://github.com/FACE-IT-project/FjordLight/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/FACE-IT-project/FjordLight/actions/workflows/R-CMD-check.yaml)
[![Codecov test coverage](https://codecov.io/gh/FACE-IT-project/FjordLight/branch/main/graph/badge.svg)](https://app.codecov.io/gh/FACE-IT-project/FjordLight?branch=main)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.10259129.svg)](https://doi.org/10.5281/zenodo.10259129)
[![Downloads](https://cranlogs.r-pkg.org/badges/grand-total/FjordLight)](https://cran.r-project.org/package=FjordLight)

This package is designed to aid the user in accessing and working with the Arctic fjord PAR data product created for the [FACE-IT project](https://www.face-it-project.eu/). An ESSD paper is currently in review that contains details on the creation of these data.

For a full range of examples for how to use this package, please see this [vignette](https://face-it-project.github.io/FjordLight/articles/fl_example.html).

The package may be installed via CRAN using:

`install.packages("FjordLight")`

or via GitHub using: 

`devtools::install_github("FACE-IT-project/FjordLight")`

## Code of Conduct
  
Please note that the FjordLight project is released with a [Contributor Code of Conduct](https://contributor-covenant.org/version/2/1/CODE_OF_CONDUCT.html). By contributing to this project, you agree to abide by its terms.

==> FjordLight_1.0.0.tar.gz: FjordLight/README.md <==
# FjordLight <img src="logo.png" width=200 align="right" />

[![CRAN_Status_Badge](http://www.r-pkg.org/badges/version/FjordLight)](https://cran.r-project.org/package=FjordLight)
[![R-CMD-check](https://github.com/FACE-IT-project/FjordLight/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/FACE-IT-project/FjordLight/actions/workflows/R-CMD-check.yaml)
[![Codecov test coverage](https://codecov.io/gh/FACE-IT-project/FjordLight/branch/main/graph/badge.svg)](https://app.codecov.io/gh/FACE-IT-project/FjordLight?branch=main)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.10259129.svg)](https://doi.org/10.5281/zenodo.10259129)
[![Downloads](https://cranlogs.r-pkg.org/badges/grand-total/FjordLight)](https://cran.r-project.org/package=FjordLight)

This package is designed to aid the user in accessing and working with the Arctic fjord PAR data product created for [FACE-IT](https://www.face-it-project.eu/). An open access [ESSD paper](https://essd.copernicus.org/articles/16/2773/2024/index.html) contains details on the creation of these data and provides examples of their use.

For a full range of examples for how to use this package, please see this [vignette](https://face-it-project.github.io/FjordLight/articles/fl_example.html).

The package may be installed via CRAN using:

`install.packages("FjordLight")`

or via GitHub using: 

`remotes::install_github("FACE-IT-project/FjordLight")`

## Code of Conduct
  
Please note that the FjordLight project is released with a [Contributor Code of Conduct](https://contributor-covenant.org/version/2/1/CODE_OF_CONDUCT.html). By contributing to this project, you agree to abide by its terms.
